#####################################################
## This script splices labeled intervals of a sound file
## with user-specified buffer and ramp from/to zero. 
## Files will be saved in a user-specified directory. 
## Files will be named with whatever is written in the interval. 
## This script needs to be in the same directory as the original files.
##
## There needs to be a sound file and TG with the same name. 
## The filename should be entered into the opening dialog box 
## WITHOUT a .wav extension
##
## jessamyn.schertz@utoronto.ca
## June 2021
#####################################################


## USER INPUT

beginPause: "User Input"
	word: "filename", "sample"
	comment: "Directory where spliced files will go"
	word: "newdir", "spliced/"
	comment: "Tier number from which labeled intervals will be spliced"
	positive: "spliceTier", 1
	comment: "Buffer duration (how much time on either side of interval)"
	positive: "bufferDur", 0.1
	comment: "Ramp duration (how much time to ramp to/from zero to normal)"
	comment: "(If this is the same as bufferDur, will ramp up/down gradually for duration of buffer)"
	positive: "rampDur", 0.3
clicked = endPause: "Continue", 1

sound = Read from file: filename$+".wav"
tg = Read from file: filename$+".TextGrid"

numInt = Get number of intervals: spliceTier
for int from 1 to numInt
	select tg
	label$ = Get label of interval: 1, int
	if label$ != ""
		start = Get starting point: 1, int
		end = Get end point: 1, int
		select sound
		soundPart = Extract part: start-bufferDur, end+bufferDur, "rectangular", 1.0, "no"
		@ramp
		newFilename$ = newdir$+label$+".wav"
		Save as WAV file: newdir$+label$+".wav"
		select soundPart
		Remove
	endif
endfor
select sound
plus tg
Remove

procedure ramp
	end = Get end time
	onsetRampEnd = rampDur
	offsetRampStart = end-rampDur
Formula... if x<(onsetRampEnd)  
	...then self * cos((x-onsetRampEnd)/'rampDur' * pi/2)
	...else self endif    
Formula... if x>(offsetRampStart)  
	...then self * cos((x-offsetRampStart)/'rampDur' * pi/2)
	...else self endif
endproc
